SegWitInfo

Enum SegWitInfo 

pub enum SegWitInfo {
    PreSegWit,
    Ambiguous,
    SegWit(WitnessVersion),
}
Defines which witness version may have an address.

The structure is required to support some ambiguity on the witness version used by some address, since Option<WitnessVersion> can’t cover that ambiguity (see details in SegWitInfo::Ambiguous description).

Variants



PreSegWit

P2PKH addresses



Ambiguous

P2SH addresses, which may be pre-segwit, segwit v0 (P2WPK/WSH-in-P2SH), non-taproot segwit v1 wrapped in P2SH, or future segwit versions wrapped in P2SH bitcoin



SegWit(WitnessVersion)

Address has a clearly defined segwit version, i.e. P2WPKH, P2WSH, P2TR or future non-P2SH-wrapped segwit address

Implementations

Source

impl SegWitInfo

pub fn witness_version(self) -> Option<WitnessVersion>

Detects WitnessVersion used in the current segwit. Returns None for both pre-segwit and P2SH (ambiguous) addresses.