pub enum InstillError {
MaxDepthExceeded,
DfsTraversal(DfsTraversalError),
}Expand description
Errors happening during tree instill operation (see
TaprootScriptTree::instill).
Variants
MaxDepthExceeded
unable to instill subtree into taproot script tree since the depth of the resulting tree exceeds taproot limit.
DfsTraversal(DfsTraversalError)
unable to instill subtree into taproot script tree since {0}