IntoNodeHash

Trait IntoNodeHash 

pub trait IntoNodeHash {
    // Required method
    fn into_node_hash(self) -> TapNodeHash;
}
Marker trait for all forms of hashes which may participate in the construction of taproot script tree.

Required Methods

fn into_node_hash(self) -> TapNodeHash

Converts leaf or branch hash into a generic SHA256 hash value, which can be used to construct hidden nodes in the tap tree.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoNodeHash for TapBranchHash

Source

fn into_node_hash(self) -> TapNodeHash

Converts this branch hash into a generic SHA256 hash value, which can be used to construct hidden nodes in the tap tree.

Source

impl IntoNodeHash for TapLeafHash

Source

fn into_node_hash(self) -> TapNodeHash

Converts this leaf hash into a generic SHA256 hash value, which can be used to construct hidden nodes in the tap tree.

Implementors